import React from 'react'
import { View } from 'react-native'
import { Calendar } from 'react-native-calendars'
import Icon from './Icon'
import { YELLOW, PALE_WHITE, DARKEST_GRAY, GRAY, BOX_SHADOW } from '../styles/theme'

export default ({ input, meta, markedDates, showPeriod, isSetToDarkMode = false }) => {
  const onChange = values => {
    console.log('values', values)
    input.onChange(values)
  }

  return (
    <View>
      <Calendar
        // Initially visible month. Default = Date()
        markedDates={markedDates}
        current={Date.now()}
        markingType={showPeriod && 'period'}
        // Handler which gets executed on day press. Default = undefined
        onDayPress={onChange}
        // Handler which gets executed on day long press. Default = undefined
        onDayLongPress={day => {
          console.log('selected day', day)
        }}
        // Month format in calendar title. Formatting values: http://arshaw.com/xdate/#Formatting
        monthFormat="yyyy MM"
        // Handler which gets executed when visible month changes in calendar. Default = undefined
        onMonthChange={month => {
          console.log('month changed', month)
        }}
        // Replace default arrows with custom ones (direction can be 'left' or 'right')
        renderArrow={direction => {
          const name = direction === 'right' ? 'next' : 'prev'
          return <Icon name={name} size={20} />
        }}
        // If firstDay=1 week starts from Monday. Note that dayNames and dayNamesShort should still start from Sunday.
        firstDay={1}
        // Hide day names. Default = false
        // Handler which gets executed when press arrow icon left. It receive a callback can go back month
        onPressArrowLeft={substractMonth => substractMonth()}
        // Handler which gets executed when press arrow icon left. It receive a callback can go next month
        onPressArrowRight={addMonth => addMonth()}
        style={{
          borderWidth: 1,
          borderColor: 'gray',
          height: 350,
          boxShadow: BOX_SHADOW,
        }}
        theme={{
          backgroundColor: 'transparent',
          calendarBackground: isSetToDarkMode ? 'transparent' : PALE_WHITE,
          textSectionTitleColor: '#b6c1cd',
          selectedDayBackgroundColor: YELLOW,
          selectedDayTextColor: DARKEST_GRAY,
          todayTextColor: 'red',
          dayTextColor: isSetToDarkMode ? PALE_WHITE : '#2d4150',
          textDisabledColor: isSetToDarkMode ? DARKEST_GRAY : GRAY,
          dotColor: '#00adf5',
          monthTextColor: 'blue',
          indicatorColor: 'blue',
          textDayFontWeight: '300',
          textMonthFontWeight: 'bold',
          textDayHeaderFontWeight: '300',
          textDayFontSize: 16,
          textMonthFontSize: 16,
          textDayHeaderFontSize: 16,
        }}
      />
    </View>
  )
}
