// @flow

import React from 'react'
import { TextInput } from 'react-native'
import MaskedInput from 'react-text-mask'

type Props = {
  label: String,
  children: $ReactElement | String,
  input: Object,
  meta: Object,
  className: String,
}

const TextField = ({ label, input, type, style, placeholder, meta: { error, touched, dirty } }: Props) => {
  const showError = (touched || dirty) && error
  const fieldId = `TextField_${input.name}`
  let Input

  switch (type) {
    case 'date':
      Input = (
        <MaskedInput
          {...input}
          placeholder={placeholder || 'YYYY/MM/DD'}
          id={fieldId}
          mask={[/\d/, /\d/, /\d/, /\d/, '/', /\d/, /\d/, '/', /\d/, /\d/]}
          render={(ref, props) => <TextInput innerRef={ref} {...props} />}
        />
      )
      break

    case 'phone':
      Input = (
        <MaskedInput
          {...input}
          guide
          placeholder={placeholder || '(123) 123-1234'}
          id={fieldId}
          mask={['(', /\d/, /\d/, /\d/, ')', ' ', /\d/, /\d/, /\d/, '-', /\d/, /\d/, /\d/, /\d/]}
          render={(ref, props) => {
            return <TextInput ref={ref} {...props} />
          }}
        />
      )
      break

    default:
      Input = <TextInput {...input} type={type} id={fieldId} placeholder={placeholder} />
  }

  return Input
}

export default TextField
