import React, { Component } from 'react'
import { Image } from 'react-native'
import styled from 'styled-components/native'

import { WHITE, BLUE, DARKEST_GRAY, DARK_GRAY, GRAY, MEDIUM_GRAY, RED_SALMON } from '../styles/theme'

const openEyeIcon = require('../assets/icons/icVisibility.png')
const closedEyeIcon = require('../assets/icons/icVisibility.png')

const OuterContainer = styled.View`
  margin-top: ${props => props.fieldMarginTop};
  margin-bottom: ${props => props.fieldMarginBottom};
`
const FieldContainer = styled.View``
const TextInput = styled.TextInput`
  flex: 1;
  height: 44;
  padding-horizontal: 16;
  font-size: 16;
  color: ${DARKEST_GRAY};
  border-width: 1;
  border-style: solid;
  border-radius: 4;
  border-color: ${props => (props.isFocused ? BLUE : props.error ? props.errorTextColor : GRAY)};
`
const LabelContainer = styled.View`
  position: absolute;
  margin-left: 16;
  max-width: 85;
  bottom: 36;
  z-index: 2;
  background-color: ${props => props.labelBackgroundColor};
  justify-content: center;
  align-items: center;
  padding-horizontal: 5;
`
const Label = styled.Text`
  color: ${props => (props.isFocused ? BLUE : props.error ? props.errorTextColor : props.labelTextColor)};
  font-size: 12;
  line-height: 15;
`
const Tooltip = styled.Text`
  font-size: 12;
  line-height: 18;
  color: ${MEDIUM_GRAY};
  margin-top: 2;
`
const ErrorText = styled.Text`
  color: ${props => props.errorTextColor};
`
const Row = styled.View`
  flex-direction: row;
  justify-content: flex-end;
`
const EyeContainer = styled.TouchableOpacity`
  width: 20;
  height: 20;
  position: absolute;
  top: 13;
  right: 10;
`

class Input extends Component {
  state = {
    isFocused: false,
    showPassword: true,
  }

  render() {
    const {
      placeholder,
      placeholderTextColor,
      autoCompleteType,
      label,
      tooltip,
      labelBackgroundColor,
      errorTextColor,
      fieldMarginTop,
      fieldMarginBottom,
      secureTextEntry,
    } = this.props

    const { showPassword } = this.state

    const Error = () => {
      if (!this.props.error || this.props.error.length === 0) {
        return null
      }
      return <ErrorText errorTextColor={errorTextColor}>{this.props.error}</ErrorText>
    }

    const handleFocus = () => {
      this.setState({ isFocused: true })
    }

    const handleBlur = () => {
      this.setState({ isFocused: false })
    }

    const handleEyePress = () => {
      const oldState = this.state.showPassword
      this.setState({ showPassword: !oldState })
    }

    return (
      <OuterContainer fieldMarginBottom={fieldMarginBottom} fieldMarginTop={fieldMarginTop}>
        <FieldContainer>
          {label && (
            <LabelContainer labelBackgroundColor={labelBackgroundColor}>
              <Label {...this.state} {...this.props}>
                {label}
              </Label>
            </LabelContainer>
          )}
          <Row>
            <TextInput
              {...this.props}
              {...this.state}
              placeholder={placeholder}
              placeholderTextColor={placeholderTextColor}
              autoCompleteType={autoCompleteType.toLowerCase()}
              autoCapitalize="none"
              onFocus={handleFocus}
              onBlur={handleBlur}
              secureTextEntry={showPassword}
            />
            {secureTextEntry && (
              <EyeContainer onPress={handleEyePress}>
                {this.state.showPassword && <Image style={{ height: 20, width: 20 }} source={closedEyeIcon} />}
                {!this.state.showPassword && <Image style={{ height: 20, width: 20 }} source={openEyeIcon} />}
              </EyeContainer>
            )}
          </Row>
        </FieldContainer>
        {tooltip && <Tooltip>{tooltip}</Tooltip>}
        <Error />
      </OuterContainer>
    )
  }
}

Input.defaultProps = {
  errorTextColor: RED_SALMON,
  labelTextColor: MEDIUM_GRAY,
  labelBackgroundColor: WHITE,
  autoCompleteType: 'off',
  fieldMarginBottom: 0,
  fieldMarginTop: 0,
}

export default Input
