// @flow

/* 
  This function will get the style when using `react-test-render` and the .toJSON() function. Since the code also seems to convert hex to rgba, it will also add a new key, `colors` with the any css attribute using colors, but with a hex string instead. e.g.

  {
    backgroundColor: 'rgba(254,221,0,1.00)',
    colors: {
      backgroundColor: '#FEDD00'
    }
  }

  This is to help testing the styles when doing tests. See `Button.test.js` for an example.
*/

import colorConvert from 'rgba-to-color'

type wrapperType = {
  props: Object<{ style: Object }>,
}

export default async function(wrapper: wrapperType) {
  if (wrapper && wrapper.props) {
    const { style } = wrapper.props

    if (typeof style !== 'object') return {}

    const colors = {}

    for (const key in wrapper.props.style) {
      if (typeof style[key] !== 'string') continue

      if (style[key].startsWith('rgba')) {
        colors[key] = colorConvert(style[key]).hex.toUpperCase()
      } else {
        continue
      }
    }

    const mergedStyle = {
      ...style,
      colors,
    }

    return mergedStyle
  }
}
